@@ -30,7 +30,7 @@ QUrl DKFiles::getUrl()
 	QString requestChannelCode = _channelCodeMap[_requestChannel];
 
 	if ( !_useLocal )
-		url.setUrl(QString("http://www.kanal23.dk/xmltv/kanalhovedstaden-7dage.xml?APP=SHOWTIME") );
+		url.setUrl(QString("http://www.xmltvepg.be/rytecxmltvnordic.gz?APP=SHOWTIME"));
 	else
 		url.setPath(QString(""));
 
@@ -44,7 +44,7 @@ DKFiles::~DKFiles()
 QString DKFiles::finishedDownload(QString channel, QIODevice *source)
 {
 	channel = "dummy";
-	QString filename = saveFile(channel, source); 
+	QString filename = saveZipFile(channel, source); 
 
 	// this method will split the huge single xml file per channel
 	// be patient this takes time
