@@ -21,11 +21,8 @@ public:
     virtual ~ESFiles();
 	virtual QUrl getUrl();
 	void initSettings();
-	virtual void updateSettingsFile();
-	virtual void checkDataStatus();
 	virtual void setInput(DownloadInput d);
 	virtual QString finishedDownload(QString channel, QIODevice *source);
-	virtual QStringList getChannelList();
 	void sendRecordMsg(QStringList data);
 
 signals:
@@ -36,14 +33,9 @@ private slots:
 	void sentRecordMsg(int exitCode, QProcess::ExitStatus exitStatus);
 
 protected:
-	void updateDownloadIndexes();
 
 private:
 	const char* HELPERPATH;
-
-	// ES channels names are different from the channel code we need during a network download request url
-	// hence we maintain this mapping as the codes dont mean much to the user while displaying the list :)
-	QMap<QString , QString> _channelCodeMap;
 };
 
 #endif // ESFILES_H
