@@ -3,9 +3,12 @@
 #include <QStandardItemModel>
 #include <QPushButton>
 #include <QListWidget>
+#include <QLineEdit>
 #include <QHBoxLayout>
 #include <QVBoxLayout>
 #include <QFile>
+#include <QAction>
+#include <QMenu>
 #include <QDebug>
 
 #include "infoaccess.h"
@@ -13,11 +16,16 @@
 #include "region.h"
 #include "favourite.h"
 
+const int CHANNEL = 1;
+const int SEARCH  = 2;
+
 FavouriteWindow::FavouriteWindow(QMainWindow *parent) : SettingsWindow(parent)
 {
 	setWindowTitle("FAVOURITES");
 	_mainwidget = new QWidget(this);
 
+	loadSettings(); // load from the file what is there currently
+
 	_regionListModel = new QStandardItemModel(this);
 	_regionSelectorList = new QMaemo5ListPickSelector(this);
 	_regionSelectorList->setModel(_regionListModel);
@@ -25,25 +33,37 @@ FavouriteWindow::FavouriteWindow(QMainWindow *parent) : SettingsWindow(parent)
 	_regionSelector = new QMaemo5ValueButton("PICK REGION", this);
 	_regionSelector->setValueLayout(QMaemo5ValueButton::ValueUnderTextCentered);
 	_regionSelector->setPickSelector(_regionSelectorList);
+	_regionSelector->setValueText(getRegion());
+	_region = getRegion();
 
 	_channelListModel = new QStandardItemModel(this);
 
 	_channelSelector = new QMaemo5ValueButton("PICK CHANNELS", this);
 	_channelSelector->setValueLayout(QMaemo5ValueButton::ValueUnderTextCentered);
 
-	_selectedListWidget = new QListWidget(this);	
+	_searchListEdit = new QLineEdit(this);
+	_searchListEdit->hide();
 
+	_selectedListWidget = new QListWidget(this);	
+	_searchListWidget = new QListWidget(this);	
+	_searchListWidget->hide(); // shown only when search title setting is chosen for channel using context menu
+
+	_backButton = new QPushButton("FAV CHANNEL LIST", this);
+	_backButton->hide(); // shown only when search title setting is chosen for channel using context menu
 	_cancelButton = new QPushButton("CANCEL", this);
 	_saveButton = new QPushButton("SAVE", this);
 
-	_h1layout = new QHBoxLayout;
-	_h2layout = new QHBoxLayout;
-	_h3layout = new QHBoxLayout;
-	_v1layout = new QVBoxLayout;
+	_h1layout = new QHBoxLayout; // layout for channel selectors
+	_h2layout = new QHBoxLayout; // layout for the list
+	_h3layout = new QHBoxLayout; // layout for the cancel/save button
+	_v1layout = new QVBoxLayout; // layout for main widget
 
 	_h1layout->addWidget(_regionSelector);
 	_h1layout->addWidget(_channelSelector);
+	_h1layout->addWidget(_searchListEdit);
 	_h2layout->addWidget(_selectedListWidget);
+	_h2layout->addWidget(_searchListWidget);
+	_h3layout->addWidget(_backButton);
 	_h3layout->addWidget(_cancelButton);
 	_h3layout->addWidget(_saveButton);
 
@@ -55,13 +75,33 @@ FavouriteWindow::FavouriteWindow(QMainWindow *parent) : SettingsWindow(parent)
 
 	setCentralWidget(_mainwidget);
 
+	_a1 = new QAction(QString("delete channel"), this);
+	_a2 = new QAction(QString("search title window"), this);
+
 	initRegionListModel();
-	loadSettings(); // load from the file what is there currently
 
 	connect(_regionSelectorList, SIGNAL(selected(QString)), this, SLOT(selectRegion(QString)));
+	connect(_searchListEdit, SIGNAL(returnPressed()), this, SLOT(addSearchTitle()));
+	connect(_backButton, SIGNAL(clicked()), this, SLOT(showSelectedListWidget()));
 	connect(_cancelButton, SIGNAL(clicked()), this, SLOT(doCancel()));
 	connect(_saveButton, SIGNAL(clicked()), this, SLOT(doSave()));
-	connect(_selectedListWidget, SIGNAL(itemClicked(QListWidgetItem*)), this, SLOT(removeChannel(QListWidgetItem*)));
+	//connect(_selectedListWidget, SIGNAL(itemClicked(QListWidgetItem*)), this, SLOT(removeChannel(QListWidgetItem*)));
+	connect(_selectedListWidget, SIGNAL(itemClicked(QListWidgetItem*)), this, SLOT(showMenu(QListWidgetItem*)));
+	connect(_searchListWidget, SIGNAL(itemClicked(QListWidgetItem*)), this, SLOT(removeSearchTitle(QListWidgetItem*)));
+	connect(_a1, SIGNAL(triggered()), this, SLOT(removeSelectedChannel()));
+	connect(_a2, SIGNAL(triggered()), this, SLOT(showSearchTitles()));
+
+	selectRegion(_region);
+}
+
+void FavouriteWindow::showMenu(QListWidgetItem* item)
+{
+	_channel = item->text();
+
+	QList<QAction*> actions;
+	actions.append(_a1);
+	actions.append(_a2);
+	QMenu::exec(actions, QCursor::pos());
 }
 
 void FavouriteWindow::initRegionListModel()
@@ -133,26 +173,69 @@ void FavouriteWindow::selectChannel(QString channel)
 	_selectedListWidget->addItem(channel);
 }
 
+void FavouriteWindow::addSearchTitle()
+{
+	//qDebug() << "Adding " << _searchListEdit->text()<< " to your list";
+
+	foreach(QString searchTitle, getSearchTitles(_region, _channel))
+	{
+		if ( searchTitle == _searchListEdit->text() )
+		{
+			//qDebug() << _searchListEdit->text() << " is already in the list";
+			return;
+		}
+	}
+
+	setSearchTitles(_region, _channel, _searchListEdit->text());
+
+	//qDebug() << getSettingsMap();
+
+	_searchListWidget->addItem(_searchListEdit->text());
+	_searchListEdit->clear();
+}
+
 void FavouriteWindow::showSelectedListWidget()
 {
-	_selectedListWidget->clear();
+	toggleList(CHANNEL);
 
 	foreach(QString channel, getFavourites(_region))
 		_selectedListWidget->addItem(channel);
 }
 
-void FavouriteWindow::removeChannel(QListWidgetItem* item)
+void FavouriteWindow::removeSelectedChannel()
 {
 	//qDebug() << "Removing " << item->text() << " from favourites";
 
-	removeFromFavourite(_region, item->text());
-	_selectedListWidget->removeItemWidget(item);
+	removeFromFavourite(_region, _channel);
+	_selectedListWidget->removeItemWidget(_selectedListWidget->currentItem());
 
 	//qDebug() << getSettingsMap();
 
 	showSelectedListWidget();
 }
 
+void FavouriteWindow::removeSearchTitle(QListWidgetItem *item)
+{
+	//qDebug() << "Removing " << item->text() << " from your list";
+
+	removeFromSearchTitles(_region, _channel, item->text());
+	_searchListWidget->removeItemWidget(item);
+
+	//qDebug() << getSettingsMap();
+
+	showSearchTitles();
+}
+
+void FavouriteWindow::showSearchTitles()
+{
+	toggleList(SEARCH);
+
+	//qDebug() << getSearchTitles(_region, _channel);
+
+	foreach(QString searchTitles, getSearchTitles(_region, _channel))
+		_searchListWidget->addItem(searchTitles);
+}
+
 void FavouriteWindow::doSave()
 {
 	updateSettings();
@@ -164,6 +247,33 @@ void FavouriteWindow::doCancel()
 	emit clicked(); // CLOSE THE WINDOW
 }
 
+void FavouriteWindow::toggleList(int listType)
+{
+	switch(listType)
+	{
+		case CHANNEL:
+			_selectedListWidget->clear();
+			_regionSelector->show();
+			_channelSelector->show();
+			_selectedListWidget->show();
+			_searchListEdit->hide();
+			_searchListWidget->hide();
+			_backButton->hide();
+			break;
+
+		case SEARCH:
+			_searchListWidget->clear();
+			_searchListWidget->show();
+			_searchListEdit->show();
+			_backButton->show();
+			_regionSelector->hide();
+			_channelSelector->hide();
+			_selectedListWidget->hide();
+			break;
+
+	}
+}
+
 FavouriteWindow::~FavouriteWindow()
 {
 }
