@@ -14,6 +14,7 @@ class QHBoxLayout;
 class QVBoxLayout;
 class QListWidget;
 class QListWidgetItem;
+class QLineEdit;
 class InfoAccess;
 class QPushButton;
 
@@ -35,14 +36,19 @@ signals:
 private slots:
 	void selectRegion(QString region);
 	void selectChannel(QString channel);
-	void removeChannel(QListWidgetItem *item);
+	void addSearchTitle();
+	void removeSelectedChannel();
+	void removeSearchTitle(QListWidgetItem* item);
+	void showMenu(QListWidgetItem *item);
+	void showSelectedListWidget();
+	void showSearchTitles();
 	void doSave();
 	void doCancel();
 
 private: // functions
 	void initRegionListModel();
 	void initChannelListModel();
-	void showSelectedListWidget();
+	void toggleList(int);
 
 private:
 	QMaemo5ValueButton *_regionSelector;
@@ -51,7 +57,9 @@ private:
 	QMaemo5ValueButton *_channelSelector;
 	QMaemo5ListPickSelector	*_channelSelectorList;
 	QStandardItemModel *_channelListModel;
+	QLineEdit	*_searchListEdit;
 
+	QPushButton *_backButton;
 	QPushButton *_cancelButton;
 	QPushButton *_saveButton;
 
@@ -62,10 +70,15 @@ private:
 	QWidget	*_mainwidget;
 
 	QListWidget	*_selectedListWidget;
+	QListWidget	*_searchListWidget;
+
+	QAction	*_a1;
+	QAction	*_a2;
 
 	InfoAccess *_infoapi;
 
 	QString _region;
+	QString _channel;
 };
 
 #endif // FAVOURITEWINDOW_H
