@@ -11,6 +11,7 @@
 class QNetworkReply;
 class DataDownloader;
 
+// struct to hold data for each programme of the channel
 struct ChannelData
 {
     QString channelId;
@@ -24,6 +25,14 @@ struct ChannelData
     QString desc;
 };
 
+struct ChannelMetaData
+{
+	QString minDate;           // min date for which data is available
+	QString maxDate;           // max date for which data is available
+	QString downloadedDate;    // date on which data was downloaded
+	QSet<QString> availableDates; // list of dates available for per day channels
+};
+
 class InfoAccess : public QObject
 {
     Q_OBJECT
@@ -34,9 +43,11 @@ public:
     virtual ~InfoAccess();
 	void setUrl(QUrl url);
     QMap<QString, QList<ChannelData> > results() const;
+    QMap<QString, ChannelMetaData> metadata() const;
 	QStringList getChannelList();
 	void sendRecordMsg(QStringList input);
     bool processXMLTV( QString filename );
+	bool isSingleXMLTVFile();
 
 signals:
     void finished( bool success );
