@@ -24,6 +24,7 @@ class QTableWidgetItem;
 class QListWidget;
 class QListWidgetItem;
 class QLabel;
+class QComboBox;
 class Reminder;
 class SettingsWindow;
 class RegionWindow;
@@ -62,10 +63,13 @@ private slots:
 	void showRegion();
 	void showFavourite();
 	void showSettings();
+	void switchMode();
 	void showHelp();
 	void reInitFavouriteSettings();
 	void reInitInfoAccess();
 	void reInitMiscSettings();
+	void addSearchString(QString);
+	void setCurrentSearchString();
 
 private: // functions
 	void initAppSettings();
@@ -81,7 +85,12 @@ private: // functions
 	void setLandscape();
 	void initPortrait();
 	void initLandscape();
+	void colorDateSelector();
 	void toggleBusy(bool isBusy);
+	// search title functionality
+	void goWeekly(QDate date = QDate::currentDate());
+	void finishedWeekly();
+	bool isRequestMoreThanMaxDate();
 
 private:
     // downloads/reads the smltv data into memory
@@ -111,6 +120,7 @@ private:
 	QAction *regionAct;
 	QAction *favAct;
 	QAction *setAct;
+	QAction *modeAct;
 	QAction *helpAct;
 	QAction *donateAct;
 
@@ -131,6 +141,7 @@ private:
     QPushButton* _backToProgrammeListButton;
     QPushButton* _clearButton;
     QPushButton* _clearProgButton;
+	QComboBox*	_searchInput;
 
 	QListWidget *_programmeList;
 	QListWidgetItem *_programmeItem;
@@ -156,6 +167,9 @@ private:
     // Map to hold the xmltv data in memory
     QMap<QString, ChannelData> _channelDataMap;
 
+    // Map to hold the dates for which xmltv data is available in memory
+    QMap<QString, QSet<QString> > _channelDataAvailableMap;
+
 	// list of selected channels
 	QStringList _channelsSelected;
 
@@ -177,6 +191,18 @@ private:
 
     // bool to indicate we are in landscape mode
 	bool _landscapeOrientation;	
+
+    // bool to indicate we are in weekly search title mode for a channel
+	bool _weeklyMode;	
+	int _dayCount; // to count the day while doing weekly download, it goes from 0 - 6.
+
+	// list of selected search titles per channel
+	QMap<QString, QString> _searchStringPerChannelMap;
+
+	// current search string
+    QString	_currentSearchString;
+
+
 };
 
 #endif // MAINWINDOW_H
