@@ -1,8 +1,11 @@
 #include <QFile>
+#include <QTime>
 #include <QDebug>
 
 #include "settings.h"
 
+QMap<QString, QStringList> SettingsWindow::_settingsMap;
+
 SettingsWindow::SettingsWindow(QMainWindow *parent) : QMainWindow(parent), BINPATH("/opt/showtime/bin/"), ICONPATH("/opt/showtime/icons/")
 {
 }
@@ -37,8 +40,6 @@ void SettingsWindow::loadSettings()
 
 void SettingsWindow::updateSettings()
 {
-	//qDebug() << "Updating Settings File";
-
 	QString filename = QString(BINPATH) + ".appsetting";
 
 	QFile::remove(filename);
@@ -54,11 +55,11 @@ void SettingsWindow::updateSettings()
 		if ( _settingsMap[key].isEmpty() )
 			continue;
 
-		// favourites are to be stored in the format UKFAV(n)=bbc1 where n=1,2,3...n
+		// favourites are to be stored in the format UKFAV=bbc1#ch4#sky1
 		t << key << "=";
 		foreach(QString value, _settingsMap[key])
 		{
-			if ( key.contains("FAV") )
+			if ( key.contains("FAV") || key.contains("SEARCH") )
 				t << value << "#";
 			else
 				t << value;
@@ -119,6 +120,38 @@ QStringList SettingsWindow::getFavourites(QString region)
 		return QStringList(); // default no favourites
 }
 
+QStringList SettingsWindow::getSearchTitles(QString region, QString channel) 
+{
+	if(_settingsMap.find(region+channel+"SEARCH") != _settingsMap.end() )
+		return _settingsMap[region+channel+"SEARCH"];
+	else
+		return QStringList(); // default no search titles
+}
+
+QString SettingsWindow::getShowPastInd()
+{
+	if(_settingsMap.find("SHOWPAST") != _settingsMap.end() )
+		return _settingsMap["SHOWPAST"].back();
+	else
+		return "Y"; // default show the past listings also
+}
+
+QString SettingsWindow::getPrimeTimeStart()
+{
+	if(_settingsMap.find("START_PRIMETIME") != _settingsMap.end() )
+		return _settingsMap["START_PRIMETIME"].back();
+	else
+		return "00:00";
+}
+
+QString SettingsWindow::getPrimeTimeEnd()
+{
+	if(_settingsMap.find("END_PRIMETIME") != _settingsMap.end() )
+		return _settingsMap["END_PRIMETIME"].back();
+	else
+		return "23:59";
+}
+
 const QString SettingsWindow::getIconPath() 
 {
 	return QString(ICONPATH + getIconType() + "/");
@@ -165,6 +198,31 @@ void SettingsWindow::removeFromFavourite(QString region, QString channel)
 	_settingsMap[region+"FAV"].removeAll(channel);
 }
 
+void SettingsWindow::setSearchTitles(QString region, QString channel, QString searchTitle) 
+{
+	_settingsMap[region+channel+"SEARCH"] << searchTitle;
+}
+
+void SettingsWindow::removeFromSearchTitles(QString region, QString channel, QString searchTitle)
+{
+	_settingsMap[region+channel+"SEARCH"].removeAll(searchTitle);
+}
+
+void SettingsWindow::setShowPastInd(QString indicator)
+{
+	_settingsMap["SHOWPAST"] = QStringList(indicator);
+}
+
+void SettingsWindow::setPrimeTimeStart(QString time)
+{
+	_settingsMap["START_PRIMETIME"] = QStringList(time);
+}
+
+void SettingsWindow::setPrimeTimeEnd(QString time)
+{
+	_settingsMap["END_PRIMETIME"] = QStringList(time);
+}
+
 SettingsWindow::~SettingsWindow()
 {
 }
